using Domain.Entities;

namespace Core.Interfaces
{
    public interface ILookUpDom
    {
        Task<IEnumerable<ELookUpItem>> CustomersListAsync(string filter, int limit = 10);
        Task<IEnumerable<ELookUpItem>> InstitutionsListAsync(string filter, int limit = 10);
        Task<IEnumerable<ELookUpItem>> PatientsListAsync(string filter, int limit = 10);
        Task<IEnumerable<ELookUpItem>> ProfessionalsListAsync(string filter, int limit = 10);
        Task<IEnumerable<ELookUpItem>> PeopleListAsync(string filter, int limit = 10);
        Task<IEnumerable<ELookUpItem>> BussinessUnitsListAsync(string filter, int limit = 10);
        Task<IEnumerable<EProductLookupItem>> ProductsListAsync(string filter, int limit = 10);
        Task<IEnumerable<ELookUpItem>> PaymentTermsListAsync(string filter, int limit = 10);
        Task<IEnumerable<ELookUpItem>> ApprovedQuotesListAsync(string filter, int limit = 10);

    }
}
